# Table of Contents

- [onboarding-guide-application-portfolio-management](<./onboarding-guide-application-portfolio-management.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Onboarding Guide for SAP LeanIX Application Portfolio Management](<./Onboarding-Guide-for-SAP-LeanIX-Application-Portfolio-Management.md>)
  - [Overview](<./Onboarding-Guide-for-SAP-LeanIX-Application-Portfolio-Management/Overview.md>)
  - [Onboarding Progress and Data Quality](<./Onboarding-Guide-for-SAP-LeanIX-Application-Portfolio-Management/Onboarding-Progress-and-Data-Quality.md>)
  - [Was this page helpful?](<./Onboarding-Guide-for-SAP-LeanIX-Application-Portfolio-Management/Was-this-page-helpful.md>)
